==> hermes-2.5.1.57.tar.gz: hermes-2.5.1.57/spec/apis/dmo/entity_reservations_spec.rb <==
# frozen_string_literal: true

require 'rails_helper'

module Hermes
  require [Hermes::Engine.root, %w[lib hermes tools specs]].flatten.join('/')
  include Rack::Test::Methods

  MUTATE_PARAMS = {
    name: 'String',
    from: 'Date',
    to: 'Date',
    housing_offer_id: 'String',
    entity_id: 'String',
  }.freeze

  ACCEPTABLE_PARAMS = %w[
    name
    from
    to
    housing_offer_id
    entity_id
  ].freeze

  VALID_OPERATORS = %w[
    $in
    $nin
    $ne
    $regex
  ].freeze


  describe Api::Dmo::EntityReservationsController, type: :api do
    routes {Hermes::Engine.routes}
    include Devise::Test::ControllerHelpers
    include JwtAuthHelper

    let!(:responsible) {create(:user)}
    let!(:entity1) {create(:entity, siret: '00000000000001', user: responsible )}
    let!(:housing_offer1) {create(:housing_offer)}
    let!(:entity_reservation1) {create(:entity_reservation, 
      entity_id: entity1.id.to_s, 
      housing_offer_id: housing_offer1.id.to_s,
      from: DateTime.now() - 30.days,
      to: DateTime.now() + 30.days,
    )}

    describe 'GET /entity_reservations' do
      before :each do
        authenticated_header(request, responsible)
        get 'index'
      end

      it 'returns status code 200' do
        expect(response).to have_http_status(200)
        expect(json['data'].map{ |ev| ev['id'] }).to include(entity_reservation1.id.to_s)
      end
    end

    describe 'POST /entity_reservations' do
      describe 'Create entity_reservation without minimal valid datas' do
        before :each do
          authenticated_header(request, responsible)
          post 'create',
               data: {
                 attributes: {
                 }
               }
        end
        it 'returns status code 422' do
          expect(response).to have_http_status(422)
        end
      end
      
      describe 'Create entity_reservation with minimal valid datas' do
        before :each do
          authenticated_header(request, responsible)
          post 'create',
               data: {
                 attributes: {
                    entity_id: entity1.id.to_s,
                    housing_offer_id: housing_offer1.id.to_s,
                    from: DateTime.now() - 30.days,
                    to: DateTime.now() + 30.days,
                 }
               }
        end
        it 'returns status code 201' do
          expect(response).to have_http_status(201)
        end
      end
    end

    MUTATE_PARAMS.each do |param, type|
      describe 'put request with ' + param.to_s + ' (' + type.to_s + ') is valid' do
        let(:params) do
          attr = {}
          attr[param] = get_typed_value(type)
          attr
        end
        before :each do
          authenticated_header(request, responsible)
          put 'update', {
              id: entity_reservation1.id,
              data: {
                  attributes: params
              }
          }
        end
        it 'returns status code 201 and the value appears in json' do
          expect(response).to have_http_status(200)
          if (type == 'Date' || type == 'DateTime')
            expect(json['data']['attributes'][param.to_s]).not_to be_empty
            expect(json['data']['attributes'][param.to_s]).not_to eq('')
          else
            expect(json['data']['attributes'][param.to_s]).to eq(get_typed_value(type))
          end
        end
      end
    end
  end
end

==> hermes-5.6.0.33.tar.gz: hermes-5.6.0.33/spec/apis/dmo/entity_reservations_spec.rb <==
# frozen_string_literal: true

require 'rails_helper'

module Hermes
  require [Hermes::Engine.root, %w[lib hermes tools specs]].flatten.join('/')
  include Rack::Test::Methods

  MUTATE_PARAMS = {
    name: 'String',
    from: 'Date',
    to: 'Date',
    housing_offer_id: ['offer1', 'offer2'],
    entity_id: ['entity1', 'entity2'],
  }.freeze

  ACCEPTABLE_PARAMS = %w[
    name
    from
    to
    housing_offer_id
    entity_id
  ].freeze

  VALID_OPERATORS = %w[
    $in
    $nin
    $ne
    $regex
  ].freeze


  describe Api::Dmo::EntityReservationsController, type: :api do
    routes {Hermes::Engine.routes}
    include Devise::Test::ControllerHelpers
    include JwtAuthHelper

    let!(:responsible) {create(:user)}
    let!(:entity1) {create(:entity, siret: '00000000000001', user: responsible )}
    let!(:housing_offer1) {create(:housing_offer)}
    let!(:entity_reservation1) {create(:entity_reservation, 
      entity_id: entity1.id.to_s, 
      housing_offer_id: housing_offer1.id.to_s,
      from: DateTime.now() - 30.days,
      to: DateTime.now() + 30.days,
    )}

    describe 'GET /entity_reservations' do
      before :each do
        authenticated_header(request, responsible)
        get 'index'
      end

      it 'returns status code 200' do
        expect(response).to have_http_status(200)
        expect(json['data'].map{ |ev| ev['id'] }).to include(entity_reservation1.id.to_s)
      end
    end

    describe 'POST /entity_reservations' do
      describe 'Create entity_reservation without minimal valid datas' do
        before :each do
          authenticated_header(request, responsible)
          post 'create',
               data: {
                 attributes: {
                 }
               }
        end
        it 'returns status code 422' do
          expect(response).to have_http_status(422)
        end
      end
      
      describe 'Create entity_reservation with minimal valid datas' do
        before :each do
          authenticated_header(request, responsible)
          post 'create',
               data: {
                 attributes: {
                    entity_id: entity1.id.to_s,
                    housing_offer_id: housing_offer1.id.to_s,
                    from: DateTime.now() - 30.days,
                    to: DateTime.now() + 30.days,
                 }
               }
        end
        it 'returns status code 201' do
          expect(response).to have_http_status(201)
        end
      end
    end

    MUTATE_PARAMS.each do |param, type|
      describe 'put request with ' + param.to_s + ' (' + type.to_s + ') is valid' do
        let(:params) do
          attr = {}
          attr[param] = get_typed_value(type)
          attr
        end
        before :each do
          authenticated_header(request, responsible)
          put 'update', {
              id: entity_reservation1.id,
              data: {
                  attributes: params
              }
          }
        end
        it 'returns status code 201 and the value appears in json' do
          expect(response).to have_http_status(200)
          if (type == 'Date' || type == 'DateTime')
            expect(json['data']['attributes'][param.to_s]).not_to be_empty
            expect(json['data']['attributes'][param.to_s]).not_to eq('')
          else
            expect(json['data']['attributes'][param.to_s]).to eq(get_typed_value(type))
          end
        end
      end
    end
  end
end
